#' Unemployment Rate Not Seasonally Adjusted
#' 
#' @format data.table with columns DATE and UNRATENSA, monthly frequency
#' @source FRED
#' @usage data(UNRATENSA)
"UNRATENSA"

#' Unemployment Rate Seasonally Adjusted
#' 
#' @format data.table with columns DATE and UNRATE, monthly frequency
#' @source FRED
#' @usage data(UNRATE)
"UNRATE"

#' S&P 500
#' 
#' @format data.table with columns DATE and SP500, daily frequency
#' @source FRED
#' @usage data(SP500)
"SP500"

#' US GDP Not Seasonally Adjusted
#' 
#' @format data.table with columns DATE and NA000334Q, quarterly frequency
#' @source FRED
#' @usage data(NA000334Q)
"NA000334Q"

#' US GDP Seasonally Adjusted
#' 
#' @format data.table with columns DATE and GDP, quarterly frequency
#' @source FRED
#' @usage data(GDP)
"GDP"

#' #' Stock & Watson US Dynamic Common Factor (1991) Data
#' #' 
#' #' @format data.table with columns date, ip (industrial production), 
#' #' gmyxpg (personal income less transfer payments), 
#' #' mtq (total manufacturing and trade sales), and 
#' #' lpnag (employeess on nonagricultural payrolls)
#' #' taken from 
#' #' @source Kim and Nelson (1999) "State-Space Models with Regime Switching" (http://econ.korea.ac.kr/~cjkim/)
#' #' @usage data(sw_dcf)
#' "sw_dcf"

